MarkdownImageConfig class
Holds configuration data for an image in a Markdown document.
Constructors
- MarkdownImageConfig({required Uri uri, String? title, String? alt, double? width, double? height})
- Creates a new MarkdownImageConfig instance.
Properties
- alt → String?
-
The alternative text for the image, displayed if the image cannot be loaded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The desired height of the image.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The title of the image, displayed on hover.
final
- uri → Uri
-
The URI of the image.
final
- width → double?
-
The desired width of the image.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited